"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdminIdentityFunctions = void 0;
const axios_1 = require("axios");
class AdminIdentityFunctions {
    constructor(identityUrl, token, userFunctions) {
        this.identityUrl = identityUrl;
        this.token = token;
        this.userFunctions = userFunctions;
        this.usersUrl = 'admin/users';
    }
    async getAllUsers() {
        var getAllUsersUrl = `${this.identityUrl}/${this.usersUrl}?per_page=${100000}`;
        var results = await axios_1.default.get(getAllUsersUrl, { headers: { Authorization: `Bearer ${this.token}` } });
        return results.data;
    }
    async getUserById(userId) {
        var getUserByIdUrl = `${this.identityUrl}/${this.usersUrl}/${userId}`;
        var result = await axios_1.default.get(getUserByIdUrl, { headers: { Authorization: `Bearer ${this.token}` } });
        return result.data;
    }
    async getUserByEmail(email) {
        var allUsers = await this.getAllUsers();
        var users = allUsers.users.filter((x) => x.email == email);
        if (users && users.length > 0) {
            return users[0];
        }
        else {
            return null;
        }
    }
    async createUser(user) {
        var updateUserUrl = `${this.identityUrl}/${this.usersUrl}`;
        var result = await axios_1.default.post(updateUserUrl, user, { headers: { Authorization: `Bearer ${this.token}` } });
        return result.data;
    }
    async updateUser(user) {
        var _a;
        var userId = (_a = (await this.getUserByEmail(user.email))) === null || _a === void 0 ? void 0 : _a.id;
        var updateUserUrl = `${this.identityUrl}/${this.usersUrl}/${userId}`;
        await axios_1.default.put(updateUserUrl, user, { headers: { Authorization: `Bearer ${this.token}` } });
    }
    async deleteUser(userId) {
        var deleteUserUrl = `${this.identityUrl}/${this.usersUrl}/${userId}`;
        await axios_1.default.delete(deleteUserUrl, { headers: { Authorization: `Bearer ${this.token}` } });
    }
    async registerUserWithMetadata(email, password, appMetaData, userMetaData) {
        var newUser = await this.userFunctions.registerUser(email, password);
        newUser.app_metadata = appMetaData;
        newUser.user_metadata = userMetaData;
        await this.updateUser(newUser);
        return newUser;
    }
    async registerUserWithAppMetadata(email, password, appMetaData) {
        var newUser = await this.userFunctions.registerUser(email, password);
        newUser.app_metadata = appMetaData;
        await this.updateUser(newUser);
        return newUser;
    }
    async inviteUserWithMetadata(email, appMetaData, userMetaData) {
        var newUser = await this.userFunctions.inviteUser(email);
        newUser.app_metadata = appMetaData;
        newUser.user_metadata = userMetaData;
        await this.updateUser(newUser);
        return newUser;
    }
    async inviteUserWithAppMetadata(email, appMetaData) {
        var newUser = await this.userFunctions.inviteUser(email);
        newUser.app_metadata = appMetaData;
        await this.updateUser(newUser);
        return newUser;
    }
    async isUserIdAdministrator(userId) {
        return await this.isUserIdInRole(userId, 'Adminsitrator');
    }
    async isUserIdInRole(userId, roleName) {
        var user = await this.getUserById(userId);
        return await this.userFunctions.isUserInRole(user, roleName);
    }
    async isUserIdInAnyRole(userId, roleNames) {
        var user = await this.getUserById(userId);
        return await this.userFunctions.isUserInAnyRole(user, roleNames);
    }
}
exports.AdminIdentityFunctions = AdminIdentityFunctions;
