"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NetlifyFunctionExtensions = void 0;
const http_status_codes_1 = require("http-status-codes");
const admin_identity_functions_1 = require("./admin-identity-functions");
const netlify_result_1 = require("./models/interfaces/netlify-result");
const user_identity_functions_1 = require("./user-identity-functions");
class NetlifyFunctionExtensions {
    constructor(event, context, identityUrlOverride = null, tokenOverride = null) {
        this.event = event;
        this.context = context;
        this.identityUrlOverride = identityUrlOverride;
        this.tokenOverride = tokenOverride;
        this.userIdentityFunctions = new user_identity_functions_1.UserIdentityFunctions(event, context);
        this.adminIdentityFunctions = new admin_identity_functions_1.AdminIdentityFunctions(this.identityUrl, this.adminToken, this.userIdentityFunctions);
    }
    get callingUser() {
        var _a;
        return (_a = this.context.clientContext) === null || _a === void 0 ? void 0 : _a.user;
    }
    get adminToken() {
        var _a, _b;
        return (_a = this.tokenOverride) !== null && _a !== void 0 ? _a : (_b = this.context.clientContext) === null || _b === void 0 ? void 0 : _b.identity.token;
    }
    get identity() {
        var _a;
        return (_a = this.context.clientContext) === null || _a === void 0 ? void 0 : _a.identity;
    }
    get identityUrl() {
        var _a, _b;
        return (_a = this.identityUrlOverride) !== null && _a !== void 0 ? _a : (_b = this.context.clientContext) === null || _b === void 0 ? void 0 : _b.identity.url;
    }
    getBodyObject() {
        var _a;
        return JSON.parse((_a = this.event.body) !== null && _a !== void 0 ? _a : '');
    }
    async registerUser(email, password) {
        return await this.userIdentityFunctions.registerUser(email, password);
    }
    async inviteUser(email) {
        return await this.userIdentityFunctions.inviteUser(email);
    }
    async updateUser(user) {
        return await this.userIdentityFunctions.updateUser(user);
    }
    async isUserAdministrator(user) {
        return await this.userIdentityFunctions.isUserAdministrator(user);
    }
    async isCallingUserInRole(roleName) {
        return await this.userIdentityFunctions.isCallingUserInRole(roleName);
    }
    async isUserInRole(user, roleName) {
        return await this.userIdentityFunctions.isUserInRole(user, roleName);
    }
    async isCallingUserInAnyRole(roleNames) {
        return this.userIdentityFunctions.isCallingUserInAnyRole(roleNames);
    }
    async isUserInAnyRole(user, roleNames) {
        return await this.userIdentityFunctions.isUserInAnyRole(user, roleNames);
    }
    async executeAsync(action, functionToExecute, errorCallback) {
        try {
            if (action == this.event.httpMethod) {
                return await functionToExecute();
            }
            else {
                return new netlify_result_1.NetlifyResult(http_status_codes_1.StatusCodes.METHOD_NOT_ALLOWED);
            }
        }
        catch (error) {
            return await errorCallback(error);
        }
    }
    async executeAsyncWithRoleCheck(action, roleNames, functionToExecute, errorCallback) {
        try {
            if (action == this.event.httpMethod) {
                if (this.callingUser) {
                    if (await this.isCallingUserInAnyRole(roleNames)) {
                        return await functionToExecute();
                    }
                    else {
                        return new netlify_result_1.NetlifyResult(http_status_codes_1.StatusCodes.FORBIDDEN);
                    }
                }
                else {
                    return new netlify_result_1.NetlifyResult(http_status_codes_1.StatusCodes.UNAUTHORIZED);
                }
            }
            else {
                return new netlify_result_1.NetlifyResult(http_status_codes_1.StatusCodes.METHOD_NOT_ALLOWED);
            }
        }
        catch (error) {
            return await errorCallback(error);
        }
    }
}
exports.NetlifyFunctionExtensions = NetlifyFunctionExtensions;
