"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserIdentityFunctions = void 0;
const axios_1 = require("axios");
class UserIdentityFunctions {
    constructor(event, context) {
        this.event = event;
        this.context = context;
    }
    get identity() {
        var _a;
        return (_a = this.context.clientContext) === null || _a === void 0 ? void 0 : _a.identity;
    }
    get callingUser() {
        var _a;
        return (_a = this.context.clientContext) === null || _a === void 0 ? void 0 : _a.user;
    }
    async registerUser(email, password) {
        var registerUserUrl = `${this.identity.url}/signup`;
        var result = await axios_1.default.post(registerUserUrl, {
            email: email,
            password: password
        });
        return result.data;
    }
    async inviteUser(email) {
        var inviteUserUrl = `${this.identity.url}/invite`;
        var result = await axios_1.default.post(inviteUserUrl, {
            email: email
        }, {
            headers: {
                Authorization: `Bearer ${this.identity.token}`
            }
        });
        return result.data;
    }
    async updateUser(user) {
        var updateUserUrl = `${this.identity.url}/user`;
        await axios_1.default.put(updateUserUrl, user, { headers: { Authorization: `Bearer ${this.identity.token}` } });
    }
    async isUserAdministrator(user) {
        return await this.isUserInRole(user, 'Administrator');
    }
    async isCallingUserInRole(roleName) {
        return this.callingUser.app_metadata.roles.some((x) => x == roleName);
    }
    async isUserInRole(user, roleName) {
        return user.app_metadata.roles.some((x) => x == roleName);
    }
    async isCallingUserInAnyRole(roleNames) {
        return this.callingUser.app_metadata.roles.some((x) => roleNames.some((y) => x == y));
    }
    async isUserInAnyRole(user, roleNames) {
        return user.app_metadata.roles.some((x) => roleNames.some((y) => x == y));
    }
}
exports.UserIdentityFunctions = UserIdentityFunctions;
